"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PopoverController = void 0;
const PropTypes = require("prop-types");
const React = require("react");
const react_native_1 = require("react-native");
class PopoverController extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.state = {
            showPopover: false,
            popoverAnchor: { x: 0, y: 0, width: 0, height: 0 },
        };
        this.onOrientationChange = () => {
            if (this.state.showPopover) {
                requestAnimationFrame(this.openPopover);
            }
        };
        this.touchable = null;
        this.setTouchableRef = (ref) => {
            this.touchable = ref;
        };
        this.openPopover = () => {
            const handle = react_native_1.findNodeHandle(this.touchable);
            if (handle) {
                react_native_1.NativeModules.UIManager.measure(handle, this.onTouchableMeasured);
            }
        };
        this.onTouchableMeasured = (x0, y0, width, height, x, y) => {
            this.setState({
                showPopover: true,
                popoverAnchor: { x, y, width, height },
            });
        };
        this.closePopover = () => this.setState({ showPopover: false });
    }
    componentDidMount() {
        react_native_1.Dimensions.addEventListener('change', this.onOrientationChange);
    }
    componentWillUnmount() {
        react_native_1.Dimensions.removeEventListener('change', this.onOrientationChange);
    }
    render() {
        return this.props.children({
            openPopover: this.openPopover,
            closePopover: this.closePopover,
            setPopoverAnchor: this.setTouchableRef,
            popoverVisible: this.state.showPopover,
            popoverAnchorRect: this.state.popoverAnchor,
        });
    }
}
exports.PopoverController = PopoverController;
PopoverController.propTypes = {
    children: PropTypes.func.isRequired,
};
//# sourceMappingURL=PopoverController.js.map